@@ -30,7 +30,6 @@ describe 'keystone' do
       'catalog_type'                       => 'sql',
       'catalog_driver'                     => false,
       'token_provider'                     => 'fernet',
-      'token_driver'                       => 'sql',
       'password_hash_algorithm'            => '<SERVICE DEFAULT>',
       'password_hash_rounds'               => '<SERVICE DEFAULT>',
       'revoke_driver'                      => 'sql',
@@ -47,8 +46,6 @@ describe 'keystone' do
       'ssl_cert_subject'                   => '/C=US/ST=Unset/L=Unset/O=Unset/CN=localhost',
       'enabled'                            => true,
       'manage_service'                     => true,
-      'database_connection'                => 'sqlite:////var/lib/keystone/keystone.db',
-      'database_idle_timeout'              => '200',
       'default_transport_url'              => '<SERVICE DEFAULT>',
       'notification_transport_url'         => '<SERVICE DEFAULT>',
       'rabbit_heartbeat_timeout_threshold' => '<SERVICE DEFAULT>',
@@ -75,7 +72,6 @@ describe 'keystone' do
       'admin_password'                     => 'admin_openstack_password',
       'catalog_type'                       => 'template',
       'token_provider'                     => 'uuid',
-      'token_driver'                       => 'kvs',
       'password_hash_algorithm'            => 'pbkdf2_sha512',
       'password_hash_rounds'               => '29000',
       'revoke_driver'                      => 'kvs',
@@ -90,8 +86,6 @@ describe 'keystone' do
       'ssl_cert_subject'                   => '/C=US/ST=Unset/L=Unset/O=Unset/CN=localhost',
       'enabled'                            => false,
       'manage_service'                     => true,
-      'database_connection'                => 'mysql://a:b@c/d',
-      'database_idle_timeout'              => '300',
       'default_transport_url'              => 'rabbit://user:pass@host:1234/virt',
       'notification_transport_url'         => 'rabbit://user:pass@host:1234/virt',
       'rabbit_heartbeat_timeout_threshold' => '60',
@@ -171,18 +165,13 @@ describe 'keystone' do
     end
 
     it 'should contain correct mysql config' do
-      is_expected.to contain_keystone_config('database/idle_timeout').with_value(param_hash['database_idle_timeout'])
-      is_expected.to contain_keystone_config('database/connection').with_value(param_hash['database_connection']).with_secret(true)
+      is_expected.to contain_class('keystone::db')
     end
 
     it { is_expected.to contain_keystone_config('token/provider').with_value(
       param_hash['token_provider']
     ) }
 
-    it 'should contain correct token driver' do
-      is_expected.to contain_keystone_config('token/driver').with_value(param_hash['token_driver'])
-    end
-
     it 'should contain correct revoke driver' do
       is_expected.to contain_keystone_config('revoke/driver').with_value(param_hash['revoke_driver'])
     end
@@ -360,7 +349,7 @@ describe 'keystone' do
           :catalog_type => 'invalid' }
       end
 
-      it_raises "a Puppet::Error", /validate_re\(\): "invalid" does not match "template|sql"/
+      it { should raise_error(Puppet::Error) }
     end
 
     describe 'when configuring catalog driver' do
@@ -420,10 +409,9 @@ describe 'keystone' do
     let :params do
       {
         'admin_token'                  => 'service_token',
-        'token_driver'                 => 'memcache',
         'cache_backend'                => 'dogpile.cache.memcached',
         'cache_backend_argument'       => ['url:SERVER1:12211'],
-        'cache_memcache_servers'       => 'SERVER1:11211,SERVER2:11211',
+        'cache_memcache_servers'       => 'SERVER1:11211,SERVER2:11211,[fd12:3456:789a:1::1]:11211',
         'memcache_dead_retry'          => '60',
         'memcache_socket_timeout'      => '2',
         'memcache_pool_maxsize'        => '1000',
@@ -443,28 +431,16 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
-    it {
-      if facts[:os_package_type] == 'debian'
-        pkg = 'python3-memcache'
-      else
-        pkg = 'python-memcache'
-      end
-      is_expected.to contain_package('python-memcache').with(
-        :name   => pkg,
-        :ensure => 'present'
-      )
-    }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
   end
 
   describe 'configure cache memcache servers if set' do
     let :params do
       {
         'admin_token'                          => 'service_token',
-        'token_driver'                         => 'noop',
         'cache_backend'                        => 'dogpile.cache.memcached',
         'cache_backend_argument'               => ['url:SERVER3:12211'],
-        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211' ],
+        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211', '[fd12:3456:789a:1::1]:11211' ],
         'memcache_dead_retry'                  => '60',
         'memcache_socket_timeout'              => '2',
         'memcache_pool_maxsize'                => '1000',
@@ -487,20 +463,18 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
     it { is_expected.to contain_oslo__cache('keystone_config').with_manage_backend_package(false) }
-    it { is_expected.not_to contain_package('python-memcache') }
   end
 
   describe 'configure cache enabled if set' do
     let :params do
       {
         'admin_token'                          => 'service_token',
-        'token_driver'                         => 'memcache',
         'cache_backend'                        => 'dogpile.cache.memcached',
         'cache_backend_argument'               => ['url:SERVER3:12211'],
         'cache_enabled'                        => true,
-        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211' ],
+        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211', '[fd12:3456:789a:1::1]:11211' ],
         'memcache_dead_retry'                  => '60',
         'memcache_socket_timeout'              => '2',
         'memcache_pool_maxsize'                => '1000',
@@ -522,21 +496,17 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
-    it { is_expected.to contain_package('python-memcache').with(
-      :name   => 'python-memcache',
-      :ensure => 'present'
-    ) }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
   end
 
   describe 'configure memcache servers with a string' do
     let :params do
       default_params.merge({
-        'cache_memcache_servers' => 'SERVER1:11211,SERVER2:11211'
+        'cache_memcache_servers' => 'SERVER1:11211,SERVER2:11211,[fd12:3456:789a:1::1]:11211'
       })
     end
 
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
   end
 
   describe 'do not configure memcache servers when not set' do
@@ -836,13 +806,11 @@ describe 'keystone' do
       it { is_expected.to contain_file('/etc/keystone/credential-keys/0').with(
         'content'   => 't-WdduhORSqoyAykuqWAQSYjg2rSRuJYySgI2xh48CI=',
         'owner'     => 'keystone',
-        'owner'     => 'keystone',
         'subscribe' => 'Anchor[keystone::install::end]',
       )}
       it { is_expected.to contain_file('/etc/keystone/credential-keys/1').with(
         'content'   => 'GLlnyygEVJP4-H2OMwClXn3sdSQUZsM5F194139Unv8=',
         'owner'     => 'keystone',
-        'owner'     => 'keystone',
         'subscribe' => 'Anchor[keystone::install::end]',
       )}
     end
@@ -1095,10 +1063,8 @@ describe 'keystone' do
           'domain_config_directory' => 'this/is/not/an/absolute/path'
         })
       end
-      it 'should raise an error' do
-        expect { should contain_file('/etc/keystone/domains') }
-          .to raise_error(Puppet::Error, %r(this/is/not/an/absolute/path" is not))
-      end
+
+      it { should raise_error(Puppet::Error) }
     end
     describe 'when setting domain directory and not using domain config' do
       let :params do
