@@ -45,6 +45,7 @@ describe 'keystone::resource::authtoken' do
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_use_advanced_pool').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/region_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('keystone_authtoken/service_token_roles').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/service_token_roles_required').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
       end
@@ -75,6 +76,7 @@ describe 'keystone::resource::authtoken' do
           :include_service_catalog      => false,
           :keyfile                      => 'somekey.key',
           :region_name                  => 'MyRegion',
+          :service_token_roles          => 'service',
           :service_token_roles_required => false,
           :token_cache_time             => '20',
         })
@@ -107,6 +109,7 @@ describe 'keystone::resource::authtoken' do
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_use_advanced_pool').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/region_name').with_value(params[:region_name])
+        is_expected.to contain_keystone_config('keystone_authtoken/service_token_roles').with_value(params[:service_token_roles])
         is_expected.to contain_keystone_config('keystone_authtoken/service_token_roles_required').with_value(params[:service_token_roles_required])
         is_expected.to contain_keystone_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
       end
@@ -151,11 +154,7 @@ describe 'keystone::resource::authtoken' do
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_pool_maxsize').with_value( params[:memcache_pool_maxsize] )
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_pool_dead_retry').with_value( params[:memcache_pool_dead_retry] )
         is_expected.to contain_keystone_config('keystone_authtoken/memcache_pool_conn_get_timeout').with_value( params[:memcache_pool_conn_get_timeout] )
-        if facts[:os_package_type] == 'debian'
-          pkg = 'python3-memcache'
-        else
-          pkg = 'python-memcache'
-        end
+
         is_expected.to contain_package('python-memcache').with(
           :name   => platform_params[:memcache_package_name],
           :ensure => 'present'
@@ -163,6 +162,17 @@ describe 'keystone::resource::authtoken' do
       end
     end
 
+    context 'when specifying IPv6 memcached_servers params' do
+      before do
+        params.merge! ({
+          :memcached_servers              => '[fd12:3456:789a:1::1]:11211',
+      })
+      end
+      it 'configures memcache severs with inet6: prefix in keystone authtoken' do
+        is_expected.to contain_keystone_config('keystone_authtoken/memcached_servers').with_value('inet6:[fd12:3456:789a:1::1]:11211')
+      end
+    end
+
     context 'memcache_security_strategy with invalid value' do
       before do
         params.merge!({ :memcache_security_strategy => 'mystrategy', })
@@ -193,11 +203,7 @@ describe 'keystone::resource::authtoken' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian' then
-            memcache_package_name = 'python3-memcache'
-          else
-            memcache_package_name = 'python-memcache'
-          end
+          memcache_package_name = 'python3-memcache'
         when 'RedHat'
           memcache_package_name = 'python-memcached'
         end
